@@ -58,6 +58,7 @@ const char *NYTP_type_of_offset(NYTP_file file);
 #define NYTP_TAG_STRING          '\'' 
 #define NYTP_TAG_STRING_UTF8     '"' 
 #define NYTP_TAG_START_DEFLATE   'z' 
+/* also add new items to nytp_tax_index below */
 
 typedef enum {
     nytp_no_tag,
@@ -95,6 +96,7 @@ size_t NYTP_write_process_start(NYTP_file ofile, unsigned int pid,
                                 unsigned int ppid, NV time_of_day);
 size_t NYTP_write_process_end(NYTP_file ofile, unsigned int pid,
                               NV time_of_day);
+size_t NYTP_write_sawampersand(NYTP_file ofile, unsigned int fid, unsigned int line);
 size_t NYTP_write_new_fid(NYTP_file ofile, unsigned int id,
                           unsigned int eval_fid, unsigned int eval_line_num,
                           unsigned int flags, unsigned int size,
